#!/usr/bin/env python
# -*- coding: utf8 -*-
from __future__ import absolute_import, division, generators, nested_scopes, print_function, unicode_literals, with_statement

from django.apps import AppConfig

class DjangoMiddlewareRequestIdConfig(AppConfig):
    name = 'django_middleware_request_id'
